@@ -1,5 +1,7 @@
+import copy
 import glob
 import os
+import pickle
 from pathlib import Path
 from unittest.mock import patch
 
@@ -139,6 +141,13 @@ def test_path_ends_with_double_period(create_torrent, multifile_content):
     assert torrent.metainfo['info']['files'] == multifile_content.exp_metainfo['info']['files']
 
 
+def test_location(create_torrent, tmp_path):
+    torrent = create_torrent()
+    assert torrent.location is None
+    torrent.path = tmp_path
+    assert torrent.location == tmp_path.parent
+
+
 def test_mode(singlefile_content, multifile_content):
     torrent = torf.Torrent()
     assert torrent.mode is None
@@ -787,6 +796,29 @@ def test_calculate_piece_size(monkeypatch):
     assert calc(400000 * 2**30) == 256 * 2**20  # noqa: E201,E222
 
 
+# "piece_size_" because "piece_size" is already used for --piece-size
+# (see conftest.py)
+@pytest.mark.parametrize(
+    argnames='length, piece_size_, exp_pieces',
+    argvalues=(
+        (0, 8, 0),
+        (1, 8, 1),
+        (7, 8, 1),
+        (8, 8, 1),
+        (9, 8, 2),
+        (55, 8, 7),
+        (56, 8, 7),
+        (57, 8, 8),
+        (123, 0, 0),
+    ),
+)
+def test_pieces(length, piece_size_, exp_pieces, create_torrent, mocker):
+    torrent = create_torrent()
+    torrent.metainfo['info']['length'] = length
+    torrent.metainfo['info']['piece length'] = piece_size_
+    assert torrent.pieces == exp_pieces
+
+
 def test_hashes(create_torrent, multifile_content):
     torrent = create_torrent()
     assert torrent.hashes == ()
@@ -1208,7 +1240,6 @@ def test_copy_when_ready(singlefile_content):
     assert t1 is not t2
 
 def test_copy_with_copy_module(singlefile_content):
-    import copy
     t1 = torf.Torrent(singlefile_content.path, comment='Asdf.',
                       randomize_infohash=True, webseeds=['http://foo'])
     t1.generate()
@@ -1220,3 +1251,23 @@ def test_copy_with_copy_module(singlefile_content):
     t2 = copy.deepcopy(t1)
     assert t1 == t2
     assert t1 is not t2
+
+
+def test_Torrent_object_is_picklable(generated_multifile_torrent):
+    t1 = generated_multifile_torrent
+    t1.path = None
+    t1.trackers = ['http://localhost:123']
+    t1.webseeds = ['http://localhost:234']
+    t1.httpseeds = ['http://localhost:345']
+    t1.private = True
+    t1.comment = 'Foo'
+    t1.source = 'ASDF'
+    t1.creation_date = 123456
+    t1.created_by = 'ME!'
+    t1.piece_size = 1048576
+    t1.randomize_infohash = True
+    t1_metainfo = copy.deepcopy(t1.metainfo.copy())
+
+    t2 = pickle.loads(pickle.dumps(t1))
+    t2_metainfo = copy.deepcopy(t2.metainfo.copy())
+    assert t2_metainfo == t1_metainfo
