@@ -17,6 +17,7 @@ import collections
 import contextlib
 import errno
 import fnmatch
+import functools
 import http.client
 import itertools
 import math
@@ -63,33 +64,6 @@ def is_md5sum(value):
     return bool(_md5sum_regex.match(value))
 
 
-def read_chunks(filepath, chunksize, prepend=bytes()):
-    """
-    Generator that yields chunks from file
-
-    `prepend` is prepended to the content of `filepath`.
-    """
-    chunk = b''
-    for pos in range(0, len(prepend), chunksize):
-        chunk = prepend[pos:pos + chunksize]
-        if len(chunk) == chunksize:
-            yield chunk
-            chunk = b''
-    try:
-        with open(filepath, 'rb') as f:
-            # Fill last chunk from prepended bytes with first bytes from file
-            if chunk:
-                chunk += f.read(chunksize - len(chunk))
-                yield chunk
-            while True:
-                chunk = f.read(chunksize)
-                if chunk:
-                    yield chunk
-                else:
-                    break  # EOF
-    except OSError as e:
-        raise error.ReadError(e.errno, filepath)
-
 def real_size(path):
     """
     Return size for `path`, which is a (link to a) file or directory
@@ -302,10 +276,25 @@ class MonitoredList(collections.abc.MutableSequence):
 
 
 class File(os.PathLike):
-    """Path-like that only accepts relative paths and also stores the file size"""
+    """Path-like that also stores the file size"""
+
     def __fspath__(self):
         return str(self._path)
 
+    def __reduce__(self):
+        # __reduce__() is needed to properly pickle File objects
+        state = (
+            # Preserve positional and keyword arguments
+            functools.partial(
+                self.__class__,
+                os.path.join(*self._path.parts),
+                size=self._size,
+            ),
+            # Mandatory positional args (already preserved by partial())
+            (),
+        )
+        return state
+
     def __init__(self, path, size):
         if isinstance(path, str):
             self._path = pathlib.Path(path)
@@ -315,6 +304,7 @@ class File(os.PathLike):
             self._path = pathlib.Path(*path)
         else:
             raise ValueError(f'Path must be str, PathLike or Iterable, not {type(path).__name__}: {path}')
+
         try:
             self._size = int(size)
         except (ValueError, TypeError):
@@ -364,6 +354,7 @@ class File(os.PathLike):
     def __repr__(self):
         return f'{type(self).__name__}({repr(str(self._path))}, size={self._size})'
 
+
 class Files(MonitoredList):
     """Deduplicated list of :class:`Files` objects"""
     def __init__(self, files, callback=None):
@@ -624,9 +615,10 @@ def download(url, timeout=60):
     """
     Download data from URL
 
-    :raises ConnectionError: if the download fails
+    :raises ConnectionError: if the download fails or the protocol is not
+        supported
 
-    :return: the downloaded data or ``None`` if the protocol is not supported
+    :return: the downloaded data
     """
     if timeout <= 0:
         raise error.ConnectionError(url, 'Timed out')
@@ -688,7 +680,7 @@ def key_exists_in_list_or_dict(key, lst_or_dct):
 
 def assert_type(obj, keys, exp_types, must_exist=True, check=None):
     """
-    Raise MetainfoError value is not of a particular type
+    Raise MetainfoError if value is not of a particular type
 
     :param obj: The object to check
     :type obj: sequence or mapping
@@ -739,7 +731,12 @@ def assert_type(obj, keys, exp_types, must_exist=True, check=None):
 
 def decode_value(value):
     if isinstance(value, collections.abc.ByteString):
-        return bytes.decode(value, encoding='utf-8', errors='replace')
+        # Torrents can contain binary data in non-standard fields. There is no
+        # way to tell if a field is supposed to be decoded as a string or not.
+        try:
+            return bytes.decode(value, encoding='utf-8', errors='strict')
+        except UnicodeDecodeError:
+            return value
     elif isinstance(value, collections.abc.Sequence):
         return decode_list(value)
     elif isinstance(value, collections.abc.Mapping):
